#
# spec file for package leiningen
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           leiningen
# Change LEIN_VERSION in lein-pkg when bumping
Version:        2.11.2
Release:        1.2
Summary:        Automation for Clojure projects
License:        EPL-1.0
Group:          Development/Tools/Building
URL:            https://leiningen.org/
Source0:        https://github.com/technomancy/leiningen/releases/download/%{version}/leiningen-%{version}-standalone.jar
# Following files are taken from the upstream repo in the `doc` and `bin` subfolders:
Source1:        https://raw.githubusercontent.com/technomancy/leiningen/stable/bin/lein-pkg
Source2:        https://raw.githubusercontent.com/technomancy/leiningen/stable/bash_completion.bash
Source3:        https://raw.githubusercontent.com/technomancy/leiningen/stable/zsh_completion.zsh
Source4:        https://raw.githubusercontent.com/technomancy/leiningen/stable/doc/lein.1
BuildRequires:  fdupes
Requires:       clojure >= 1.10.0
Requires:       java >= 1.8.0
BuildArch:      noarch

%description
Working on Clojure projects with tools designed for Java can be an
exercise in frustration. With Leiningen, builds can be describe with
Clojure. Leiningen handles fetching dependencies, running tests,
packaging projects and can be extended with a number of plugins.

%prep

%build

%install
#LEIN_JAR =
mkdir -p %{buildroot}%{_datadir}/java/
install -m 0644 -D %{SOURCE0} %{buildroot}%{_datadir}/java/leiningen-%{version}-standalone.jar
install -m 0755 -D %{SOURCE1} %{buildroot}%{_bindir}/lein
install -m 0644 -D %{SOURCE2} %{buildroot}%{_datadir}/bash-completion/completions/lein
install -m 0644 -D %{SOURCE3} %{buildroot}%{_sysconfdir}/zsh_completion.d/_lein
install -m 0644 -D %{SOURCE4} %{buildroot}%{_mandir}/man1/lein.1

%fdupes %{buildroot}/%{_prefix}

%files
%{_bindir}/lein
%{_mandir}/man1/lein*
%{_datadir}/bash-completion/completions/lein
%{_sysconfdir}/zsh_completion.d
%dir %{_datadir}/java
%{_datadir}/java/leiningen-%{version}-standalone.jar

%changelog
* Wed Feb 14 2024 Michael Vetter <mvetter@suse.com>
- Update to 2.11.2:
  * Add :preserve-eval-meta setting to avoid project code reflection.
  * Fix a bug where metadata on project code caused plugin
    incompatibilities.
* Mon Jan 29 2024 Michael Vetter <mvetter@suse.com>
- Update to 2.11.1:
  * Fix a bug when deploying using passwords read from the console.
* Sun Jan 28 2024 Michael Vetter <mvetter@suse.com>
- Update to 2.11.0:
  * Top-level :exclusions can now affect top-level :dependencies.
  * Fix a bug where :eval-in :nrepl couldn't detect running repl.
  * Fix a bug where :eval-in :nrepl would crash.
  * Fix a bug where files on test path could be visible during jar.
  * Fix an issue with check in namespaces that rely on AOT.
  * Fix a redundant confusing dependencies warning.
  * Add static-classpath task for static analysis.
  * Major performance improvements handling pathological dependency trees.
  * Improve error reporting for search failures.
  * Support XDG config directories.
  * Use $XDG_CACHE_HOME for self-installs if it exists.
  * Add warnings for buggy composite profiles.
* Mon Dec 12 2022 Michael Vetter <mvetter@suse.com>
- Update to 2.10.0:
  * Update to nREPL 1.0.0
  * Fix a bug where :eval-in :leiningen could suppress test exit code.
  * Add the ability to sign deployed files using SSH keys, not just GPG.
  * Fix a bug where uberjar splices profiles into target path
    incorrectly.
* Thu Aug 11 2022 Michael Vetter <mvetter@suse.com>
- Update to 2.9.10:
  * Fix a bug where dev-resources could leak into jars/uberjars.
  * Avoid illegal reflective access doing XML parsing in uberjar/search.
* Mon Aug  8 2022 Michael Vetter <mvetter@suse.com>
- Update to 2.9.9:
  * Migrate the repository from Github to Codeberg.
  * Fix a bug in new where template group-ids could be ignored.
  * Work around a change in Java 9 which broke template listing.
  * Fix a bug in pedantic checks which resulted in infinite loops.
  * Prevent module-info.class files from being included in uberjars.
  * Prevent duplicate warnings in resource-paths when creating jars.
  * Fix an issue with check where AOT would shadow reflection warnings.
  * Allow change to edit dependency versions.
  * Fix a bug where composite profiles would leak dependencies downstream.
  * Allow repl to bind to filesystem sockets via :headless :socket PATH
* Mon Dec  6 2021 Michael Vetter <mvetter@suse.com>
- Update to 2.9.8:
  * Fix a bug where certain deep dependency trees would overflow
    stack.
  * Allow LEIN_JAR to be overridden if you install elsewhere.
* Thu Sep 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 2.9.7:
  * Detect certain pathological dependency trees and warn.
  * Bump to Clojure 1.10.3.
  * Don't warn on version ranges which point to a single version.
  * Fix a bug where verifying deps could loop forever.
  * Get better error messages when deploys fail.
* Wed Jul 14 2021 Michael Vetter <mvetter@suse.com>
- Own java dir
* Mon Apr 19 2021 Michael Vetter <mvetter@suse.com>
- Update to 2.9.6:
  * Look for templates in a way that reflects new Clojars group rules.
  * Update template-generating template to reflect new Clojars rules.
  * Don't :reload in tests unless connecting to an nrepl.
* Tue Dec  8 2020 Michael Vetter <mvetter@suse.com>
- Update to 2.9.5:
  * Several dependency version bumps.
* Thu Jul  9 2020 Michael Vetter <mvetter@suse.com>
- Update to 2.9.4:
  * Fix a bug where dependency conflict resolution errors were wrong.
  * Make test selectors skip non-test vars.
  * Fix a bug where deps :query would report incorrect results.
  * Update nREPL to 0.7.
  * Add scheme configuration support to REPL-y and use configured
    transport when starting the ack-server.
* Wed May  6 2020 Michael Vetter <mvetter@suse.com>
- boo#1171255 - leiningen does not work: ClassNotFoundException:
  Use correct version in bash script
* Tue Mar 17 2020 Michael Vetter <mvetter@suse.com>
- Update to 2.9.3:
  * Fix a bug where deploying would fail to send signature checksums.
  * Memoize application of project middleware.
  * Fix a bug where checksum verification failed on non-GNU systems.
* Wed Mar  4 2020 Michael Vetter <mvetter@suse.com>
- Update to 2.9.2:
  * Bump to Clojure 1.10.1.
  * Fix a bug where disabling implicit middleware disabled explicit ones.
  * Add checksum check during self-install process.
  * Include repository auth when verifying dependencies.
  * Fix bugs in certain kinds of profile merging.
  * Include :repositories from project.clj in pom.xml file.
* Mon Aug 26 2019 Jan Engelhardt <jengelh@inai.de>
- Trim filler wording from descriptions.
* Tue Jul 16 2019 mvetter@suse.com
- Update to 2.9.1:
  * Fix a bug where provided namespace compilation order was overridden. (Phil Hagelberg)
  * Don't emit namespaced maps when merging data readers for uberjar. (Joel Kaasinen)
- Install to correct bash completions path
- Remove suse macros
- Use standalone leiningen
- Add files from upstream:
  * bash_completion.bash
  * zsh_completion.bash
  * lein.1 manpage
  * lein-pkg script
* Tue Jul 16 2019 mvetter@suse.com
- Remove PKGBUILD
* Thu Feb 19 2015 kgronlund@suse.com
- Update to 2.5.1
  - Completion scripts are now bundled in the distribution.
* Sun Jan 12 2014 kgronlund@suse.com
- Initial version.
